WcsSampler
==========

.. currentmodule:: toasty.samplers

.. autoclass:: WcsSampler
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~WcsSampler.filter
      ~WcsSampler.sampler

   .. rubric:: Methods Documentation

   .. automethod:: filter
   .. automethod:: sampler
